#include <stdlib.h>
#include <string.h>
// Author: Robert Obryk

#include <algorithm>
#include <cstdio>
#include <vector>
#include <cassert>

#define fprintf(...) 

using namespace std;

const int SMSZ = 10;

struct smallgraph {
    smallgraph() {
        for(int i=0;i<SMSZ;i++)
            for(int j=0;j<SMSZ;j++)
                edges[i][j] =false;
    }
    int n;
    bool edges[SMSZ][SMSZ];

    bool used[SMSZ]; // OUT
    int maxres;

    bool usednow[SMSZ];
    int res;

    void backtrack(int i) {
        for(;i < n && usednow[i]; i++) {
        }
        if (i == n) {
            if (res > maxres) {
                maxres = res;
                for(int j=0;j<n;j++)
                    used[j] = usednow[j];
            } else if (res == maxres) {
                for(int j=0;j<n;j++)
                    used[j] = used[j] && usednow[j];
            }
            return;
        }
        for(int j=i+1;j<n;j++)
            if (edges[i][j] && !usednow[j]) {
                assert(!usednow[i]);
                assert(!usednow[j]);
                res++;
                usednow[i] = true;
                usednow[j] = true;
                backtrack(i+1);
                usednow[j] = false;
                usednow[i] = false;
                res--;
            }
        backtrack(i+1);
    }

    void dostuff() {
        assert(n <= SMSZ);
        res = maxres = 0;
        for(int i=0;i<n;i++)
            used[i] = usednow[i] = false;
        backtrack(0);
    }
};

struct scase {
    vector<vector<int> > sas;
    vector<int> parent;
    vector<int> depth;
    vector<vector<int> > ancestors; // [i] = 2^i-parent

    vector<vector<pair<int, int> > > pairs;
    vector<vector<int> > mypairs;

    int parentdfs(int v) {
        int cnt = 1;
        for(int w : sas[v]) {
            if (w != parent[v]) {
                parent[w] = v;
                ancestors[w].push_back(v);
                depth[w] = depth[v] + 1;
                cnt += parentdfs(w);
            }
        }
        return cnt;
    }

    void fill_ancestors() {
        for(int i=0;(1<<i) <= ancestors.size() + 5; i++) {
            for(int v=0;v<ancestors.size();v++) {
                int a = ancestors[v][i];
                if (a != -1)
                    a = ancestors[a][i];
                ancestors[v].push_back(a);
            }
        }
    }

    int go_up(int v, int k) {
        for(int i=0;(1<<i) <= k; i++) {
            if (k & (1<<i)) {
                v = ancestors[v][i];
                k -= (1 << i);
            }
        }
        assert(k == 0);
        return v;
    }

    int lca(int u, int v) {
        if (depth[u] > depth[v]) {
            u = go_up(u, depth[u] - depth[v]);
        } else if (depth[v] > depth[u]) {
            v = go_up(v, depth[v] - depth[u]);
        }
        if (u == v)
            return u;
        int step = 1;
        while ((1<<step) < depth[u]) step++;
        
        while (parent[u] != parent[v]) {
            assert(step >= 0);
            if (ancestors[u][step] != ancestors[v][step]) {
                u = ancestors[u][step];
                v = ancestors[v][step];
                assert(ancestors[u][step] == ancestors[v][step]);
            }
            step--;
        }
        return parent[u];
    }

    int res;

    void dostuff() {
        int n;
        scanf("%d", &n);
        sas.resize(n);
        parent.resize(n);
        ancestors.resize(n);
        depth.resize(n);
        pairs.resize(n);
        mypairs.resize(n);

        for(int i=0;i<n-1;i++) {
            int a, b;
            scanf("%d%d", &a, &b);
            a--;b--;
            sas[a].push_back(b);
            sas[b].push_back(a);
        }
        depth[0] = 0;
        parent[0] = -1;
        ancestors[0].push_back(-1);
        assert(parentdfs(0) == n);
        fill_ancestors();

        int m;
        scanf("%d", &m);
        for(int i=0;i<m;i++) {
            int a, b;
            scanf("%d%d", &a, &b);
            a--;b--;
            mypairs[a].push_back(b);
            mypairs[b].push_back(a);
            int v = lca(a, b);
            pairs[v].push_back(make_pair(a, b));
        }

        // reading done
        res = 0;
        (void)maindfs(0);
        printf("%d\n", res);
    }


    // returns available vertices, adjusts res
    vector<int> maindfs(int v) {
        vector<int> children;
        vector<vector<int> > child_avail;
        for(int i=0;i<sas[v].size();i++)
            if (sas[v][i] != parent[v]) {
                children.push_back(sas[v][i]);
                child_avail.push_back(maindfs(sas[v][i]));
            }
        for(int i=0;i<child_avail.size();) {
            bool found = false;
            for(int w : mypairs[v]) {
                if (binary_search(child_avail[i].begin(), child_avail[i].end(), w)) {
                    found = true;
                    break;
                }
            }
            if (found) {
                fprintf(stderr, "%d: +1 on %d\n", v, children[i]);
                res++;
                children.erase(children.begin() + i);
                child_avail.erase(child_avail.begin() + i);
            } else {
                i++;
            }
        }
        smallgraph sg;
        sg.n = children.size();
        for(const auto& p : pairs[v]) {
            int first = -1, second = -1;
            for(int i=0;i<children.size();i++) {
                if (binary_search(child_avail[i].begin(), child_avail[i].end(), p.first))
                    first = i;
                if (binary_search(child_avail[i].begin(), child_avail[i].end(), p.second))
                    second = i;
            }
            if (first != -1 && second != -1) {
                sg.edges[first][second] = true;
                sg.edges[second][first] = true;
            }
        }
        sg.dostuff();
        fprintf(stderr, "%d: resmax %d\n", v, sg.maxres);
        res += sg.maxres;
        vector<int> avail_vtx;
        avail_vtx.push_back(v);
        for(int i=0;i<child_avail.size();i++) {
            if (!sg.used[i]) {
                fprintf(stderr, "%d: visible %d\n", v, children[i]);
                for(int w : child_avail[i])
                    avail_vtx.push_back(w);
            }
        }
        sort(avail_vtx.begin(), avail_vtx.end());
        return avail_vtx;
    }
};

int main()
{
    int t;
    scanf("%d", &t);
    while (t--) {
        scase s;
        s.dostuff();
    }
}
