#include <stdio.h>
#include <string.h>
#include <algorithm>
#include <cstdlib>
#include <iostream>
#include <set>
#include <utility>
#include <vector>
using namespace std;

const int MAXDEG = 10;
const int MAXN = 1000;

typedef pair<int, int> Edge;

vector<Edge> edges, pairs;

int Nodes() { return edges.size() + 1; }

void RandSwap(Edge &e) { if (rand() & 1) swap(e.first, e.second); }

void Print() {
  cerr << "n = " << Nodes() << " m = " << pairs.size() << endl;
  vector<int> p(Nodes());
  for (int i = 0; i < Nodes(); ++i)
    p[i] = i + 1;
  random_shuffle(p.begin(), p.end());
  random_shuffle(edges.begin(), edges.end());
  cout << Nodes() << endl;
  for (int i = 0; i < edges.size(); ++i) {
    RandSwap(edges[i]);
    cout << p[edges[i].first] << " " << p[edges[i].second] << endl;
  }
  random_shuffle(pairs.begin(), pairs.end());
  cout << pairs.size() << endl;
  for (int i = 0; i < pairs.size(); ++i) {
    RandSwap(pairs[i]);
    cout << p[pairs[i].first] << " " << p[pairs[i].second] << endl;
  }
}

void GenPairs(int m) {
  pairs.clear();
  if (m < 0) {
    for (int i = 0; i < Nodes(); ++i)
      for (int j = i + 1; j < Nodes(); ++j)
        pairs.push_back(Edge(i, j));
  } else {
    set<Edge> s;
    while (m--) {
      int a, b;
      do { a = rand() % Nodes(); b = rand() % Nodes(); } while (!(a < b));
      if (s.count(Edge(a, b)))
        continue;
      s.insert(Edge(a, b));
      pairs.push_back(Edge(a, b));
    }
  }
}

void GenRand(int n) {
  edges.clear();
  vector<int> deg(n);
  for (int i = 1; i < n; ++i) {
    int p;
    do {
      p = rand() % i;
    } while (deg[p] >= MAXDEG - 1);
    ++deg[p];
    edges.push_back(Edge(i, p));
  }
}

void GenPath(int n) {
  edges.clear();
  for (int i = 0; i < n - 1; ++i)
    edges.push_back(Edge(i, i + 1));
}

void GenDeep(int n) {
  edges.clear();
  for (int i = 1; i < n; ++i)
    edges.push_back(Edge(i, i - 1 - rand() % min(i, MAXDEG - 1)));
}

void GenShallow(int n) {
  edges.clear();
  for (int i = 1; i < n; ++i)
    edges.push_back(Edge(i, i / (MAXDEG - 1)));
}

void GenTriStarWithPairs(int n) {
  edges.clear();
  edges.push_back(Edge(0, 1));
  edges.push_back(Edge(0, 2));
  for (int i = 3; i < n; ++i)
    edges.push_back(Edge(i - 3, i));
  pairs.clear();
  for (int i = 1; i < n; ++i)
    for (int j = i + 1; j < n; ++j)
      if (i % 3 != j % 3)
        pairs.push_back(Edge(i, j));
}

int main() {
  srand(0x79ee);
  cout << 1 + 16 + 80 << endl;

  GenTriStarWithPairs(MAXN);
  Print();

  for (auto Gen : {GenRand, GenPath, GenDeep, GenShallow}) {
    Gen(MAXN);
    GenPairs(-1);
    Print();
  }

  for (double m : {0.1, 0.5, 4.0}) {
    for (auto Gen : {GenRand, GenPath, GenDeep, GenShallow}) {
      Gen(MAXN - rand() % (MAXN / 2));
      GenPairs(m * Nodes());
      Print();
    }
  }

  for (int i = 1; i <= 80; ++i) {
    GenRand(40 + rand() % 11);
    GenPairs(5 * i);
    Print();
  }
}
