// Author: Adam Polak
// O(n^2)

#include <cstring>
#include <iostream>
using namespace std;

const int MAXL = 1e6;
const int MOD = 1e9 + 9;

char s1[MAXL + 1], s2[MAXL + 1], s3[MAXL + 1];
int n1, n2, n3;
long long prefeq[MAXL + 2];
long long suf1[MAXL + 2], suf2[MAXL + 2], suf3[MAXL + 2];
long long pow26[MAXL + 2];
int diff12[MAXL + 2], diff23[MAXL + 2], any12[MAXL + 2], any23[MAXL + 2];

int WaysEqual(char a, char b, char c) {
  if (a == '?' && b == '?' && c == '?')
    return 26;
  if (a != '?' && b != '?' && a != b)
    return 0;
  if (b != '?' && c != '?' && b != c)
    return 0;
  if (c != '?' && a != '?' && c != a)
    return 0;
  return 1;
}

int WaysLess(char a, char b) {
  if (a == '?' && b == '?')
    return 25 * 26 / 2;
  if (a != '?' && b != '?')
    return a < b ? 1 : 0;
  if (a == '?')
    return b >= 'a' ? (b - 'a') : 0;
  if (b == '?')
    return 'z' - a;
}

int WaysLessEqual(char a, char b, char c) {
  if (b != c && b != '?' && c != '?')
    return 0;
  if (b == '?')
    return WaysLess(a, c);
  else
    return WaysLess(a, b);
}

int WaysEqualLess(char a, char b, char c) {
  if (a != b && a != '?' && b != '?')
    return 0;
  if (b == '?')
    return WaysLess(a, c);
  else
    return WaysLess(b, c);
}

int WaysLessLess(char a, char b, char c) {
  // cerr << "Ways<< " << a << " " << b << " " << c << endl;
  int a_start = a == '?' ? 'a' : a;
  int a_end   = a == '?' ? 'z' : a;
  int b_start = b == '?' ? 'a' : b;
  int b_end   = b == '?' ? 'z' : b;
  int c_start = c == '?' ? 'a' : c;
  int c_end   = c == '?' ? 'z' : c;
  // cerr << a_start << " " << a_end << " " << b_start << " " << b_end << " " << c_start << " " << c_end << endl;
  int count = 0;
  for (int x = b_start; x <= b_end; ++x)
    count +=
      max(0, min(a_end, x - 1) - a_start + 1) *
      max(0, c_end - max(c_start, x + 1) + 1);
  // cerr << count << endl;
  return count;
}

int main() {
  ios_base::sync_with_stdio(false);
  
  pow26[0] = 1;
  for (int i = 1; i < MAXL + 2; ++i)
    pow26[i] = (pow26[i - 1] * 26) % MOD;
  
  int Z;
  cin >> Z;
  while (Z--) {
    cin >> s1 >> s2 >> s3;
    n1 = strlen(s1);
    n2 = strlen(s2);
    n3 = strlen(s3);
    s1[n1] = s2[n2] = s3[n3] = 'a' - 1;

    prefeq[0] = 1;
    for (int i = 0; i <= min(n1, min(n2, n3)); ++i)
      prefeq[i + 1] = (prefeq[i] * WaysEqual(s1[i], s2[i], s3[i])) % MOD;

    suf1[n1 + 1] = 1;
    for (int i = n1; i >= 0; --i)
      suf1[i] = (suf1[i + 1] * (s1[i] == '?' ? 26 : 1)) % MOD;
    suf2[n2 + 1] = 1;
    for (int i = n2; i >= 0; --i)
      suf2[i] = (suf2[i + 1] * (s2[i] == '?' ? 26 : 1)) % MOD;
    suf3[n3 + 1] = 1;
    for (int i = n3; i >= 0; --i)
      suf3[i] = (suf3[i + 1] * (s3[i] == '?' ? 26 : 1)) % MOD;

    diff12[0] = 0;
    for (int i = 0; i <= min(n1, n2); ++i)
      diff12[i + 1] = diff12[i] + ((s1[i] != s2[i] && s1[i] != '?' && s2[i] != '?') ? 1 : 0);
    diff23[0] = 0;
    for (int i = 0; i <= min(n2, n3); ++i)
      diff23[i + 1] = diff23[i] + ((s2[i] != s3[i] && s2[i] != '?' && s3[i] != '?') ? 1 : 0);
    any12[0] = 0;
    for (int i = 0; i <= min(n1, n2); ++i)
      any12[i + 1] = any12[i] + ((s1[i] == '?' && s2[i] == '?') ? 1 : 0);
    any23[0] = 0;
    for (int i = 0; i <= min(n2, n3); ++i)
      any23[i + 1] = any23[i] + ((s2[i] == '?' && s3[i] == '?') ? 1 : 0);

    long long total = 0;
    for (int a = 0; a <= min(n1, n2); ++a) {
      for (int b = 0; b <= min(n2, n3); ++b) {
        long long count = 1;
        count = (count * prefeq[min(a, b)]) % MOD;
        count = (count * suf1[a + 1]) % MOD;
        count = (count * suf2[max(a, b) + 1]) % MOD;
        count = (count * suf3[b + 1]) % MOD;

        if (a + 1 < b) {
          if (diff23[a + 1] != diff23[b])
            count = 0;
          else
            count = (count * pow26[any23[b] - any23[a + 1]]) % MOD;
        }
        if (b + 1 < a) {
          if (diff12[b + 1] != diff12[a])
            count = 0;
          else
            count = (count * pow26[any12[a] - any12[b + 1]]) % MOD;
        }

        if (a < b) {
          count = (count * WaysLess(s2[b], s3[b])) % MOD;
          count = (count * WaysLessEqual(s1[a], s2[a], s3[a])) % MOD;
        } else if (a == b) {
          count = (count * WaysLessLess(s1[a], s2[a], s3[a])) % MOD;
        } else {  // a > b
          count = (count * WaysLess(s1[a], s2[a])) % MOD;
          count = (count * WaysEqualLess(s1[b], s2[b], s3[b])) % MOD;
        }
        total = (total + count) % MOD;
      }
    }
    cout << total << endl;
  }
}
