#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

#define sz(x) ((int) (x).size())
#define pb push_back
#define mp make_pair
#define fi first
#define se second

#define NAME "b"

struct pt
{
	ll x, y;
	
	explicit pt(ll nx = 0, ll ny = 0): x(nx), y(ny) {}

	pt operator + (const pt &p) const
	{
		return pt(x + p.x, y + p.y);
	}
	
	pt operator - (const pt &p) const
	{
		return pt(x - p.x, y - p.y);
	}
	
	ll operator * (const pt &p) const
	{
		return x * p.x + y * p.y;
	}
	
	
	ll operator % (const pt &p) const
	{
		return x * p.y - y * p.x;
	}
};

const int maxn = 130000;
const int treeSize = 1 << 18;

pt data[maxn];

struct hull
{
	vector<int> pts;
	
	void clear()
	{
		pts.clear();
	}
	
	bool below(const pt &s, const pt &v)
	{
		if (pts.empty()) 
			return true;
		pt n = pt(-v.y, v.x);
		int l = 0, r = pts.size() - 2;
		if (pts.size() == 1) 
			return data[pts[0]] * n <= s * n;
//		cerr << l << " " << r << endl;
//		cerr << n.x << " " << n.y << endl;
		while (l < r)
		{
			int m = (l + r) / 2 + 1;
//			cerr << m << endl;
			pt to = data[pts[m + 1]] - data[pts[m]];
			if (to * n >= 0)
				l = m;
			else
				r = m - 1;
		}
		ll maxp = max(n * data[pts[l]], n * data[pts[l + 1]]);
		return n * s >= maxp;
	}
};

hull tree[treeSize];
int n, halfSize;

void build_hull(int l, int r, vector<int> &hull)
{
	hull.clear();
	for (int i = l; i <= r; ++i)
	{
		while (sz(hull) > 1)
		{
			if ((data[i] - data[hull[sz(hull) - 2]]) % (data[hull.back()] - data[hull[sz(hull) - 2]]) > 0)
				break;
			hull.pop_back();
		}
		hull.pb(i);
	}
}

void build(int v, int tl, int tr)
{
	tree[v].clear();
	if (tl >= n) return;
	build_hull(tl, min(tr - 1, n - 1), tree[v].pts);
	if (tl + 1 == tr) return;
	int m = (tl + tr) / 2;
	build(v * 2, tl, m);
	build(v * 2 + 1, m, tr);
}

int go(int l, const pt &s, const pt &dir)
{
	int v = l + halfSize;
	while (true)
	{
		if (!tree[v].below(s, dir))
			break;
		if (((v + 1) & v) == 0) 
			return 0;
		if (v & 1) ++v;
		else v /= 2;
	}
	while (true)
	{
		int l = v * 2;
		if (l >= 2 * halfSize) break;
		if (tree[l].below(s, dir)) v = v * 2 + 1;
		else v = v * 2;
	}
	return v - halfSize;
}

void solve()
{
	cin >> n;
	for (int i = 0; i < n; ++i)
		cin >> data[i].x >> data[i].y;
	
	halfSize = 1;
	while (halfSize < n) halfSize *= 2;
	build(1, 0, halfSize);
	
//	cerr << "ANS = " << tree[1].below(data[0], data[1] - data[0]) << endl;
	//return;
	for (int i = 0; i + 1 < n; ++i)
		printf("%d ", go(i + 1, data[i], data[i + 1] - data[i]));
	printf("\n");
}

int main()
{
	#ifdef LOCAL
	assert(freopen(NAME ".in", "r", stdin));
	#endif // LOCAL
	int t;
	cin >> t;
	while (t --> 0)
		solve();
	#ifdef LOCAL
	cerr << "Time: " << double(clock()) / CLOCKS_PER_SEC << "\n";
	#endif // LOCAL
	return 0;
}
