#include <algorithm>
#include <stack>
#include <cassert>
#include <cmath>
#include <complex>
#include <cstdio>
#include <cstring>
#include <iostream>
#include <map>
#include <set>
#include <string>
#include <sstream>
#include <vector>
using namespace std;

typedef pair<int, int> ii;
typedef vector<int> vi;
typedef vector<ii> vii;
typedef vector<vector<int> > vvi;
typedef long long ll;
template <class T> int size(const T& x) {return x.size();}

const double EPS = 1e-9;
const int INF = 2147483647;

int gcd(int a, int b) {
    return b == 0 ? a : gcd(b, a % b);
}

struct fraction {
    int x, y;
    fraction(int _x = 0, int _y = 1) {
        int g = gcd(_x, _y);
        if (g == 0) {
            g = 1;
        }
        x = _x / g;
        y = _y / g;
    }

    fraction operator *(const fraction &other) const {
        return fraction(x * other.x, y * other.y);
    }

    fraction operator /(const fraction &other) const {
        return fraction(x * other.y, y * other.x);
    }

    void outp() {
        printf("%d", x);
        if (y != 1) {
            printf("/%d", y);
        }
    }
};

struct circle {
    int x, y, r;
    fraction speed;
    bool dir;
    bool visited;

    circle() {
    }

    void inp() {
        scanf("%d %d %d\n", &x, &y, &r);
        visited = false;
        dir = true;
    }
    void outp() {
        if (!visited) {
            printf("not moving\n");
        } else {
            speed.outp();
            printf(" ");
            if (dir) printf("clockwise\n");
            else printf("counterclockwise\n");
        }
    }
    bool intersects(const circle &other) {
        int d2 = (x - other.x) * (x - other.x) + (y - other.y) * (y - other.y);
        return d2 <= (r + other.r) * (r + other.r);
    }
};

int main() {

    int ts;
    scanf("%d\n", &ts);

    for (int t = 0; t < ts; t++) {
        int n;
        scanf("%d\n", &n);

        circle *arr = new circle[n];
        for (int i = 0; i < n; i++) {
            arr[i].inp();
        }

        vi *adj = new vi[n];
        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                if (arr[i].intersects(arr[j])) {
                    adj[i].push_back(j);
                    adj[j].push_back(i);
                }
            }
        }

        arr[0].speed = fraction(1,1);

        stack<int> S;
        S.push(0);
        arr[0].visited = true;
        while (!S.empty())  {
            int cur = S.top();
            S.pop();

            //printf("on %d\n", cur);
            //arr[cur].outp();

            for (int i = 0; i < size(adj[cur]); i++) {
                int nxt = adj[cur][i];
                //printf("%d\n", nxt);
                if (arr[nxt].visited)
                    continue;
                arr[nxt].visited = true;

                arr[nxt].speed = arr[cur].speed * arr[cur].r / arr[nxt].r;
                arr[nxt].dir = !arr[cur].dir;
                S.push(nxt);
            }
        }

        for (int i = 0; i < n; i++) {
            arr[i].outp();
        }
    }

    return 0;
}
